@@ -10,18 +10,18 @@ use Log::ger;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-23'; # DATE
 our $DIST = 'App-DataDirUtils'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our %SPEC;
 
 $SPEC{':package'} = {
     v => 1.1,
-    summary => 'CLI utilities related to datadirs',
+    summary => '(DEPRECATED) CLI utilities related to datadirs',
 };
 
 our %argspecs_common = (
     prefixes => {
-        summary => 'Changes file',
+        summary => 'Locations to find datadirs',
         schema => ['array*', of=>'dirname*'],
         req => 1,
         pos => 0,
@@ -137,7 +137,7 @@ sub list_datadirs {
 }
 
 1;
-# ABSTRACT: CLI utilities related to datadirs
+# ABSTRACT: (DEPRECATED) CLI utilities related to datadirs
 
 __END__
 
@@ -147,11 +147,16 @@ __END__
 
 =head1 NAME
 
-App::DataDirUtils - CLI utilities related to datadirs
+App::DataDirUtils - (DEPRECATED) CLI utilities related to datadirs
 
 =head1 VERSION
 
-This document describes version 0.002 of App::DataDirUtils (from Perl distribution App-DataDirUtils), released on 2021-08-23.
+This document describes version 0.003 of App::DataDirUtils (from Perl distribution App-DataDirUtils), released on 2021-08-23.
+
+=head1 DEPRECATION NOTICE
+
+This distribution is deprecated in favor of the more general
+L<App::TaggedDirUtils>.
 
 =head1 SYNOPSIS
 
@@ -198,7 +203,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<prefixes>* => I<array[dirname]>
 
-Changes file.
+Locations to find datadirs.
 
 Directory name(s) to search for "datadirs", i.e. directories which have
 C<.tag-datadir> file in its root.
@@ -257,6 +262,10 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-DataDi
 
 Source repository is at L<https://github.com/perlancar/perl-App-DataDirUtils>.
 
+=head1 SEE ALSO
+
+L<App::TaggedDirUtils> is the more general utility.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
